@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.1.0'
+    version = '1.1.1'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -61,9 +61,9 @@ class DingDingPlugin(NotificationPlugin):
 
         count = self.getGroupCount(group.id)
 
-        if(count>2){
+        if(count>2):
             return
-        }
+        
 
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
